@@ -3,11 +3,10 @@
 
 """Utilities to measure OCR quality."""
 
-
 from __future__ import annotations
 
 import re
-from typing import Iterable
+from collections.abc import Iterable
 
 
 class OcrQualityDictionary:
